==> gschedwicons-0.1.1.tar.gz: gschedwicons-0.1.1/src/callbacks.h <==
#include <gnome.h>



void
on_quit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about2_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_properties2_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_host_edit_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_refresh_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_where_used_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_edit_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_where_used_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_refresh_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_show_hosts_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_show_environments_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_application_main_delete_event       (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_certificate_save_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_view_certificate_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_cal_list_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_cal_close_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_list_year_prev_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_list_year_next_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_refresh_clicked          (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_treeview_cal_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_cal_popup_menu             (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_host_list_edit_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_host_list_references_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_edit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_references_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_treeview_hosts_button_press_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_hosts_popup_menu           (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_treeview_environments_button_press_event
                                        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_environments_popup_menu    (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_cal_menu_edit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_references_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_okbutton_cal_folder_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_edit_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_year_prev_preview_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_year_next_preview_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_cal_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_cal_where_used_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_show_calendars_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_dialog_host_list_delete_event       (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_host_list_close_clicked      (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_env_list_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_env_list_close_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_location_bar_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoomin_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoomout_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_normal_size_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_status_bar_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_eventbox_main_navigator_button_press_event
                                        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_button_main_zoom_out_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_main_zoom_in_clicked         (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_canvas_main_scroll_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_refresh_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_toolbutton_refresh_clicked          (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_entry_main_location_activate        (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_button_find_select_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_find_close_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_find_activate                 (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_button_find_find_clicked            (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_find_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_toolbutton_find_clicked             (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_find_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_entry_pref_database_server_changed  (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_entry_pref_database_server_changed  (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_entry_pref_database_name_changed    (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_fileentry_database_socket_changed   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_spinbutton_pref_cal_num_month_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_combobox_pref_cal_first_day_changed (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_fontbutton_pref_cal_font_font_set   (GtkFontButton   *fontbutton,
                                        gpointer         user_data);

void
on_radiobutton_pref_cal_font_theme_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_dialog_preferences_delete_event     (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_closebutton_pref_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_pref_database_username_changed
                                        (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_spinbutton_pref_database_port_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_button_pref_database_revert_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_pref_database_test_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_database_test_connect_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_database_assistant_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_login1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_logout1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_login_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_druid_connect_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_druidpagefinish1_finish             (GnomeDruidPage  *gnomedruidpage,
                                        GtkWidget       *widget,
                                        gpointer         user_data);

void
on_default_job_parameters1_activate    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_statistics1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);


void
on_combobox_main_workload_changed      (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_spinbutton_main_update_interval_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_start_now1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stop_now1_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_completed1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_failed1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_waiting1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_running1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

==> gschedwicons-0.1.2.tar.gz: gschedwicons-0.1.2/src/callbacks.h <==
#include <gnome.h>



void
on_quit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about2_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_properties2_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_host_edit_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_refresh_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_where_used_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_edit_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_where_used_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_refresh_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_show_hosts_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_show_environments_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_application_main_delete_event       (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_certificate_save_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_view_certificate_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_cal_list_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_cal_close_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_list_year_prev_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_list_year_next_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_refresh_clicked          (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_treeview_cal_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_cal_popup_menu             (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_host_list_edit_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_host_list_references_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_edit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_references_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_treeview_hosts_button_press_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_hosts_popup_menu           (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_treeview_environments_button_press_event
                                        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_environments_popup_menu    (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_cal_menu_edit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_references_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_okbutton_cal_folder_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_edit_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_year_prev_preview_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_year_next_preview_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_cal_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_cal_where_used_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_show_calendars_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_dialog_host_list_delete_event       (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_host_list_close_clicked      (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_env_list_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_env_list_close_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_location_bar_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoomin_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoomout_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_normal_size_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_status_bar_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_eventbox_main_navigator_button_press_event
                                        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_button_main_zoom_out_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_main_zoom_in_clicked         (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_canvas_main_scroll_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_refresh_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_toolbutton_refresh_clicked          (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_entry_main_location_activate        (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_button_find_select_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_find_close_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_find_activate                 (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_button_find_find_clicked            (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_find_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_toolbutton_find_clicked             (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_find_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_entry_pref_database_server_changed  (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_entry_pref_database_server_changed  (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_entry_pref_database_name_changed    (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_fileentry_database_socket_file_set   (GtkFileChooserButton     *editable,
                                        gpointer         user_data);

void
on_spinbutton_pref_cal_num_month_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_combobox_pref_cal_first_day_changed (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_fontbutton_pref_cal_font_font_set   (GtkFontButton   *fontbutton,
                                        gpointer         user_data);

void
on_radiobutton_pref_cal_font_theme_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_dialog_preferences_delete_event     (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_closebutton_pref_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_pref_database_username_changed
                                        (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_spinbutton_pref_database_port_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_button_pref_database_revert_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_pref_database_test_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_database_test_connect_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_database_assistant_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_login1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_logout1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_login_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_druid_connect_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_druidpagefinish1_finish             (GnomeDruidPage  *gnomedruidpage,
                                        GtkWidget       *widget,
                                        gpointer         user_data);

void
on_default_job_parameters1_activate    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_statistics1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);


void
on_combobox_main_workload_changed      (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_spinbutton_main_update_interval_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_start_now1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stop_now1_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_completed1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_failed1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_waiting1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_force_to_running1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);
